@@ -3,7 +3,7 @@ package Digest::MD5;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '2.10';  # $Date: 2000/08/18 08:44:24 $
+$VERSION = '2.18';  # $Date: 2002/05/01 23:30:28 $
 
 require Exporter;
 *import = \&Exporter::import;
@@ -16,11 +16,18 @@ eval {
     Digest::MD5->bootstrap($VERSION);
 };
 if ($@) {
-    # Try to load the pure perl version
-    require Digest::Perl::MD5;
+    my $olderr = $@;
+    eval {
+	# Try to load the pure perl version
+	require Digest::Perl::MD5;
 
-    Digest::Perl::MD5->import qw(md5 md5_hex md5_base64);
-    push(@ISA, "Digest::Perl::MD5");  # make OO interface work
+	Digest::Perl::MD5->import(qw(md5 md5_hex md5_base64));
+	push(@ISA, "Digest::Perl::MD5");  # make OO interface work
+    };
+    if ($@) {
+	# restore the original error
+	die $olderr;
+    }
 }
 else {
     *reset = \&new;
@@ -88,6 +95,10 @@ Same as md5(), but will return the digest in hexadecimal form.
 
 Same as md5(), but will return the digest as a base64 encoded string.
 
+The base64 encoded string returned is not padded to be a multiple of 4
+bytes long.  If you want interoperability with other base64 encoded
+md5 digests you might want to append the string "==" to the result.
+
 =back
 
 =head1 METHODS
@@ -102,7 +113,7 @@ The constructor returns a new C<Digest::MD5> object which encapsulate
 the state of the MD5 message-digest algorithm.  You can add data to
 the object and finally ask for the digest.
 
-If called as a instance method (i.e. $md5->new) it will just reset the
+If called as an instance method (i.e. $md5->new) it will just reset the
 state the object to the state of a newly created object.  No new
 object is created in this case.
 
@@ -121,6 +132,9 @@ The $io_handle is read until EOF and the content is appended to the
 message we calculate the digest for.  The return value is the $md5
 object itself.
 
+In most cases you want to make sure that the $io_handle is set up to
+be in binmode().
+
 =item $md5->digest
 
 Return the binary digest for the message.
@@ -139,6 +153,10 @@ Same as $md5->digest, but will return the digest in hexadecimal form.
 Same as $md5->digest, but will return the digest as a base64 encoded
 string.
 
+The base64 encoded string returned is not padded to be a multiple of 4
+bytes long.  If you want interoperability with other base64 encoded
+md5 digests you might want to append the string "==" to the result.
+
 =back
 
 
@@ -212,7 +230,7 @@ RFC 1321
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
- Copyright 1998-2000 Gisle Aas.
+ Copyright 1998-2002 Gisle Aas.
  Copyright 1995-1996 Neil Winton.
  Copyright 1991-1992 RSA Data Security, Inc.
 
@@ -256,6 +274,6 @@ licenses.
 The original MD5 interface was written by Neil Winton
 (C<N.Winton@axion.bt.co.uk>).
 
-This release was made by Gisle Aas <gisle@aas.no>
+This release was made by Gisle Aas <gisle@ActiveState.com>
 
 =cut
